@@ -33,7 +33,7 @@ describe('cooperative request interception', function () {
           if (request.url().endsWith('.css')) {
             void request.continue(
               {headers: {...request.headers(), xaction: 'continue'}},
-              expectedAction === 'continue' ? 1 : 0
+              expectedAction === 'continue' ? 1 : 0,
             );
           } else {
             void request.continue({}, 0);
@@ -43,7 +43,7 @@ describe('cooperative request interception', function () {
           if (request.url().endsWith('.css')) {
             void request.respond(
               {headers: {xaction: 'respond'}},
-              expectedAction === 'respond' ? 1 : 0
+              expectedAction === 'respond' ? 1 : 0,
             );
           } else {
             void request.continue({}, 0);
@@ -75,7 +75,7 @@ describe('cooperative request interception', function () {
               page.goto(server.PREFIX + '/one-style.html'),
             ]);
             actionResults.push(
-              serverRequest.headers['xaction'] as ActionResult
+              serverRequest.headers['xaction'] as ActionResult,
             );
             return response;
           } else {
@@ -104,10 +104,9 @@ describe('cooperative request interception', function () {
           expect(request.url()).toContain('empty.html');
           expect(request.headers()['user-agent']).toBeTruthy();
           expect(request.method()).toBe('GET');
-          expect(request.postData()).toBe(undefined);
           expect(request.isNavigationRequest()).toBe(true);
-          expect(request.frame()!.url()).toBe('about:blank');
           expect(request.frame() === page.mainFrame()).toBe(true);
+          expect(request.frame()!.url()).toBe('about:blank');
         } catch (error) {
           requestError = error;
         } finally {
@@ -121,7 +120,6 @@ describe('cooperative request interception', function () {
       }
 
       expect(response.ok()).toBe(true);
-      expect(response.remoteAddress().port).toBe(server.PORT);
     });
     // @see https://github.com/puppeteer/puppeteer/pull/3105
     it('should work when POST is redirected with 302', async () => {
@@ -178,7 +176,7 @@ describe('cooperative request interception', function () {
       page.on('request', request => {
         const headers = Object.assign({}, request.headers(), {
           foo: 'bar',
-          origin: undefined, // remove "origin" header
+          accept: undefined, // remove "accept" header
         });
         void request.continue({headers}, 0);
       });
@@ -188,7 +186,7 @@ describe('cooperative request interception', function () {
         page.goto(server.PREFIX + '/empty.html'),
       ]);
 
-      expect(serverRequest.headers.origin).toBe(undefined);
+      expect(serverRequest.headers.accept).toBe(undefined);
     });
     it('should contain referer header', async () => {
       const {page, server} = await getTestState();
@@ -196,10 +194,10 @@ describe('cooperative request interception', function () {
       await page.setRequestInterception(true);
       const requests: HTTPRequest[] = [];
       page.on('request', request => {
+        void request.continue({}, 0);
         if (!isFavicon(request)) {
           requests.push(request);
         }
-        void request.continue({}, 0);
       });
       await page.goto(server.PREFIX + '/one-style.html');
       expect(requests[1]!.url()).toContain('/one-style.css');
@@ -342,7 +340,7 @@ describe('cooperative request interception', function () {
       ]);
       expect(failedRequest).toBeTruthy();
       expect(failedRequest.failure()!.errorText).toBe(
-        'net::ERR_INTERNET_DISCONNECTED'
+        'net::ERR_INTERNET_DISCONNECTED',
       );
     });
     it('should send referer', async () => {
@@ -386,23 +384,25 @@ describe('cooperative request interception', function () {
       const requests: HTTPRequest[] = [];
       page.on('request', request => {
         void request.continue({}, 0);
-        requests.push(request);
+        if (!isFavicon(request)) {
+          requests.push(request);
+        }
       });
       server.setRedirect(
         '/non-existing-page.html',
-        '/non-existing-page-2.html'
+        '/non-existing-page-2.html',
       );
       server.setRedirect(
         '/non-existing-page-2.html',
-        '/non-existing-page-3.html'
+        '/non-existing-page-3.html',
       );
       server.setRedirect(
         '/non-existing-page-3.html',
-        '/non-existing-page-4.html'
+        '/non-existing-page-4.html',
       );
       server.setRedirect('/non-existing-page-4.html', '/empty.html');
       const response = await page.goto(
-        server.PREFIX + '/non-existing-page.html'
+        server.PREFIX + '/non-existing-page.html',
       );
       expect(response!.status()).toBe(200);
       expect(response!.url()).toContain('empty.html');
@@ -526,7 +526,9 @@ describe('cooperative request interception', function () {
       await page.setRequestInterception(true);
       const requests: HTTPRequest[] = [];
       page.on('request', request => {
-        requests.push(request);
+        if (!isFavicon(request)) {
+          requests.push(request);
+        }
         void request.continue({}, 0);
       });
       const dataURL = 'data:text/html,<div>yo</div>';
@@ -542,11 +544,13 @@ describe('cooperative request interception', function () {
       await page.setRequestInterception(true);
       const requests: HTTPRequest[] = [];
       page.on('request', request => {
-        !isFavicon(request) && requests.push(request);
         void request.continue({}, 0);
+        if (!isFavicon(request)) {
+          requests.push(request);
+        }
       });
       const dataURL = 'data:text/html,<div>yo</div>';
-      const text = await page.evaluate((url: string) => {
+      const text = await page.evaluate(url => {
         return fetch(url).then(r => {
           return r.text();
         });
@@ -561,14 +565,16 @@ describe('cooperative request interception', function () {
       await page.setRequestInterception(true);
       const requests: HTTPRequest[] = [];
       page.on('request', request => {
-        requests.push(request);
+        if (!isFavicon(request)) {
+          requests.push(request);
+        }
         void request.continue({}, 0);
       });
       const response = await page.goto(server.EMPTY_PAGE + '#hash');
       expect(response!.status()).toBe(200);
-      expect(response!.url()).toBe(server.EMPTY_PAGE);
+      expect(response!.url()).toBe(server.EMPTY_PAGE + '#hash');
       expect(requests).toHaveLength(1);
-      expect(requests[0]!.url()).toBe(server.EMPTY_PAGE);
+      expect(requests[0]!.url()).toBe(server.EMPTY_PAGE + '#hash');
     });
     it('should work with encoded server', async () => {
       const {page, server} = await getTestState();
@@ -580,7 +586,7 @@ describe('cooperative request interception', function () {
         return request.continue({}, 0);
       });
       const response = await page.goto(
-        server.PREFIX + '/some nonexisting page'
+        server.PREFIX + '/some nonexisting page',
       );
       expect(response!.status()).toBe(404);
     });
@@ -588,7 +594,7 @@ describe('cooperative request interception', function () {
       const {page, server} = await getTestState();
 
       await page.setRequestInterception(true);
-      server.setRoute('/malformed?rnd=%911', (_req, res) => {
+      server.setRoute('/malformed', (_req, res) => {
         return res.end();
       });
       page.on('request', request => {
@@ -597,7 +603,7 @@ describe('cooperative request interception', function () {
       const response = await page.goto(server.PREFIX + '/malformed?rnd=%911');
       expect(response!.status()).toBe(200);
     });
-    it('should work with encoded server - 2', async () => {
+    it('should work with missing stylesheets', async () => {
       const {page, server} = await getTestState();
 
       // The requestWillBeSent will report URL as-is, whereas interception will
@@ -606,12 +612,12 @@ describe('cooperative request interception', function () {
       const requests: HTTPRequest[] = [];
       page.on('request', request => {
         void request.continue({}, 0);
-        requests.push(request);
+        if (!isFavicon(request)) {
+          requests.push(request);
+        }
       });
-      const response = await page.goto(
-        `data:text/html,<link rel="stylesheet" href="${server.PREFIX}/fonts?helvetica|arial"/>`
-      );
-      expect(response!.status()).toBe(200);
+      const response = (await page.goto(server.PREFIX + '/style-404.html'))!;
+      expect(response.status()).toBe(200);
       expect(requests).toHaveLength(2);
       expect(requests[1]!.response()!.status()).toBe(404);
     });
@@ -629,7 +635,7 @@ describe('cooperative request interception', function () {
         (frame, url) => {
           return (frame.src = url as string);
         },
-        server.EMPTY_PAGE
+        server.EMPTY_PAGE,
       ),
       // Wait for request interception.
       await waitEvent(page, 'request'));
@@ -667,52 +673,57 @@ describe('cooperative request interception', function () {
         void request.continue({}, 0);
       });
       await page.goto(
-        pathToFileURL(path.join(__dirname, '../assets', 'one-style.html'))
+        pathToFileURL(path.join(__dirname, '../assets', 'one-style.html')),
       );
       expect(urls.size).toBe(2);
       expect(urls.has('one-style.html')).toBe(true);
       expect(urls.has('one-style.css')).toBe(true);
     });
-    it('should not cache if cache disabled', async () => {
-      const {page, server} = await getTestState();
+    for (const {resourceType, url} of [
+      {url: '/cached/one-style.html', resourceType: 'stylesheet'},
+      {url: '/cached/one-script.html', resourceType: 'script'},
+    ]) {
+      it(`should not cache ${resourceType} if cache disabled`, async () => {
+        const {page, server} = await getTestState();
 
-      // Load and re-load to make sure it's cached.
-      await page.goto(server.PREFIX + '/cached/one-style.html');
+        // Load and re-load to make sure it's cached.
+        await page.goto(server.PREFIX + url);
 
-      await page.setRequestInterception(true);
-      await page.setCacheEnabled(false);
-      page.on('request', request => {
-        return request.continue({}, 0);
+        await page.setRequestInterception(true);
+        await page.setCacheEnabled(false);
+        page.on('request', request => {
+          return request.continue({}, 0);
+        });
+
+        const cached: HTTPRequest[] = [];
+        page.on('requestservedfromcache', r => {
+          return cached.push(r);
+        });
+
+        await page.reload();
+        expect(cached).toHaveLength(0);
       });
+      it(`should cache ${resourceType} if cache enabled`, async () => {
+        const {page, server} = await getTestState();
 
-      const cached: HTTPRequest[] = [];
-      page.on('requestservedfromcache', r => {
-        return cached.push(r);
+        // Load and re-load to make sure it's cached.
+        await page.goto(server.PREFIX + url);
+
+        await page.setRequestInterception(true);
+        await page.setCacheEnabled(true);
+        page.on('request', request => {
+          return request.continue({}, 0);
+        });
+
+        const cached: HTTPRequest[] = [];
+        page.on('requestservedfromcache', r => {
+          return cached.push(r);
+        });
+
+        await page.reload();
+        expect(cached).toHaveLength(1);
       });
-
-      await page.reload();
-      expect(cached).toHaveLength(0);
-    });
-    it('should cache if cache enabled', async () => {
-      const {page, server} = await getTestState();
-
-      // Load and re-load to make sure it's cached.
-      await page.goto(server.PREFIX + '/cached/one-style.html');
-
-      await page.setRequestInterception(true);
-      await page.setCacheEnabled(true);
-      page.on('request', request => {
-        return request.continue({}, 0);
-      });
-
-      const cached: HTTPRequest[] = [];
-      page.on('requestservedfromcache', r => {
-        return cached.push(r);
-      });
-
-      await page.reload();
-      expect(cached).toHaveLength(1);
-    });
+    }
     it('should load fonts if cache enabled', async () => {
       const {page, server} = await getTestState();
 
@@ -722,10 +733,11 @@ describe('cooperative request interception', function () {
         return request.continue({}, 0);
       });
 
-      await page.goto(server.PREFIX + '/cached/one-style-font.html');
-      await page.waitForResponse(r => {
+      const responsePromise = page.waitForResponse(r => {
         return r.url().endsWith('/one-style.woff');
       });
+      await page.goto(server.PREFIX + '/cached/one-style-font.html');
+      await responsePromise;
     });
   });
 
@@ -839,7 +851,7 @@ describe('cooperative request interception', function () {
             },
             body: 'Yo, page!',
           },
-          0
+          0,
         );
       });
       const response = await page.goto(server.EMPTY_PAGE);
@@ -848,7 +860,7 @@ describe('cooperative request interception', function () {
       expect(
         await page.evaluate(() => {
           return document.body.textContent;
-        })
+        }),
       ).toBe('Yo, page!');
     });
     it('should be able to access the response', async () => {
@@ -861,7 +873,7 @@ describe('cooperative request interception', function () {
             status: 200,
             body: 'Yo, page!',
           },
-          0
+          0,
         );
       });
       let response = null;
@@ -882,7 +894,7 @@ describe('cooperative request interception', function () {
             status: 422,
             body: 'Yo, page!',
           },
-          0
+          0,
         );
       });
       const response = await page.goto(server.EMPTY_PAGE);
@@ -891,7 +903,7 @@ describe('cooperative request interception', function () {
       expect(
         await page.evaluate(() => {
           return document.body.textContent;
-        })
+        }),
       ).toBe('Yo, page!');
     });
     it('should redirect', async () => {
@@ -910,13 +922,13 @@ describe('cooperative request interception', function () {
               location: server.EMPTY_PAGE,
             },
           },
-          0
+          0,
         );
       });
       const response = await page.goto(server.PREFIX + '/rrredirect');
       expect(response!.request().redirectChain()).toHaveLength(1);
       expect(response!.request().redirectChain()[0]!.url()).toBe(
-        server.PREFIX + '/rrredirect'
+        server.PREFIX + '/rrredirect',
       );
       expect(response!.url()).toBe(server.EMPTY_PAGE);
     });
@@ -926,14 +938,14 @@ describe('cooperative request interception', function () {
       await page.setRequestInterception(true);
       page.on('request', request => {
         const imageBuffer = fs.readFileSync(
-          path.join(__dirname, '../assets', 'pptr.png')
+          path.join(__dirname, '../assets', 'pptr.png'),
         );
         void request.respond(
           {
             contentType: 'image/png',
             body: imageBuffer,
           },
-          0
+          0,
         );
       });
       await page.evaluate(PREFIX => {
@@ -960,7 +972,7 @@ describe('cooperative request interception', function () {
             },
             body: 'Yo, page!',
           },
-          0
+          0,
         );
       });
       const response = await page.goto(server.EMPTY_PAGE);
@@ -970,7 +982,7 @@ describe('cooperative request interception', function () {
       expect(
         await page.evaluate(() => {
           return document.body.textContent;
-        })
+        }),
       ).toBe('Yo, page!');
     });
     it('should indicate already-handled if an intercept has been handled', async () => {
